package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.SiteSkill;

/**
 * 师傅技能配置Service接口
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
public interface ISiteSkillService 
{
    /**
     * 查询师傅技能配置
     * 
     * @param id 师傅技能配置主键
     * @return 师傅技能配置
     */
    public SiteSkill selectSiteSkillById(Long id);

    /**
     * 查询师傅技能配置列表
     * 
     * @param siteSkill 师傅技能配置
     * @return 师傅技能配置集合
     */
    public List<SiteSkill> selectSiteSkillList(SiteSkill siteSkill);

    /**
     * 新增师傅技能配置
     * 
     * @param siteSkill 师傅技能配置
     * @return 结果
     */
    public int insertSiteSkill(SiteSkill siteSkill);

    /**
     * 修改师傅技能配置
     * 
     * @param siteSkill 师傅技能配置
     * @return 结果
     */
    public int updateSiteSkill(SiteSkill siteSkill);

    /**
     * 批量删除师傅技能配置
     * 
     * @param ids 需要删除的师傅技能配置主键集合
     * @return 结果
     */
    public int deleteSiteSkillByIds(Long[] ids);

    /**
     * 删除师傅技能配置信息
     * 
     * @param id 师傅技能配置主键
     * @return 结果
     */
    public int deleteSiteSkillById(Long id);
}
