package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SiteSkill;
import com.ruoyi.system.service.ISiteSkillService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 师傅技能配置Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/SiteSkill")
public class SiteSkillController extends BaseController
{
    @Autowired
    private ISiteSkillService siteSkillService;

    /**
     * 查询师傅技能配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:SiteSkill:list')")
    @GetMapping("/list")
    public TableDataInfo list(SiteSkill siteSkill)
    {
        startPage();
        List<SiteSkill> list = siteSkillService.selectSiteSkillList(siteSkill);
        return getDataTable(list);
    }

    /**
     * 导出师傅技能配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:SiteSkill:export')")
    @Log(title = "师傅技能配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SiteSkill siteSkill)
    {
        List<SiteSkill> list = siteSkillService.selectSiteSkillList(siteSkill);
        ExcelUtil<SiteSkill> util = new ExcelUtil<SiteSkill>(SiteSkill.class);
        util.exportExcel(response, list, "师傅技能配置数据");
    }

    /**
     * 获取师傅技能配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:SiteSkill:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(siteSkillService.selectSiteSkillById(id));
    }

    /**
     * 新增师傅技能配置
     */
    @PreAuthorize("@ss.hasPermi('system:SiteSkill:add')")
    @Log(title = "师傅技能配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SiteSkill siteSkill)
    {
        return toAjax(siteSkillService.insertSiteSkill(siteSkill));
    }

    /**
     * 修改师傅技能配置
     */
    @PreAuthorize("@ss.hasPermi('system:SiteSkill:edit')")
    @Log(title = "师傅技能配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SiteSkill siteSkill)
    {
        return toAjax(siteSkillService.updateSiteSkill(siteSkill));
    }

    /**
     * 删除师傅技能配置
     */
    @PreAuthorize("@ss.hasPermi('system:SiteSkill:remove')")
    @Log(title = "师傅技能配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(siteSkillService.deleteSiteSkillByIds(ids));
    }
}
